@@ -240,6 +240,8 @@ delete_adls_filesystem.adls_endpoint <- function(endpoint, name, confirm=TRUE, .
 #'
 #' `upload_adls_file` and `download_adls_file` can display a progress bar to track the file transfer. You can control whether to display this with `options(azure_storage_progress_bar=TRUE|FALSE)`; the default is TRUE.
 #'
+#' `adls_file_exists` and `adls_dir_exists` test for the existence of a file and directory, respectively.
+#'
 #' @section AzCopy:
 #' `upload_azure_file` and `download_azure_file` have the ability to use the AzCopy commandline utility to transfer files, instead of native R code. This can be useful if you want to take advantage of AzCopy's logging and recovery features; it may also be faster in the case of transferring a very large number of small files. To enable this, set the `use_azcopy` argument to TRUE.
 #'
@@ -478,3 +480,16 @@ adls_file_exists <- function(filesystem, file)
     httr::stop_for_status(res, storage_error_message(res))
     return(TRUE)
 }
+
+#' @rdname adls
+#' @export
+adls_dir_exists <- function(filesystem, dir)
+{
+    if(dir == "/")
+        return(TRUE)
+
+    props <- try(get_storage_properties(filesystem, dir), silent=TRUE)
+    if(inherits(props, "try-error"))
+        return(FALSE)
+    props[["x-ms-resource-type"]] == "directory"
+}
